@@ -15,7 +15,7 @@ oneTimeTearDown() {
 
 setUp () {
     echo
-    rm -f "$test_dir/catch_output"
+    rm -f "$TMPDIR/catch_output"
 }
 
 test_create() {
@@ -35,15 +35,13 @@ test_activates () {
 }
 
 test_hooks () {
-    export pre_test_dir=$(cd "$test_dir"; pwd)
-
     echo "#!/bin/sh" > "$WORKON_HOME/premkvirtualenv"
-    echo "echo GLOBAL premkvirtualenv \`pwd\` \"\$@\" >> \"$pre_test_dir/catch_output\"" >> "$WORKON_HOME/premkvirtualenv"
+    echo "echo GLOBAL premkvirtualenv \`pwd\` \"\$@\" >> \"$TMPDIR/catch_output\"" >> "$WORKON_HOME/premkvirtualenv"
     chmod +x "$WORKON_HOME/premkvirtualenv"
 
-    echo "echo GLOBAL postmkvirtualenv >> $test_dir/catch_output" > "$WORKON_HOME/postmkvirtualenv"
+    echo "echo GLOBAL postmkvirtualenv >> $TMPDIR/catch_output" > "$WORKON_HOME/postmkvirtualenv"
     mkvirtualenv "env3" >/dev/null 2>&1
-    output=$(cat "$test_dir/catch_output")
+    output=$(cat "$TMPDIR/catch_output")
     workon_home_as_pwd=$(cd $WORKON_HOME; pwd)
     expected="GLOBAL premkvirtualenv $workon_home_as_pwd env3
 GLOBAL postmkvirtualenv"
@@ -51,7 +49,7 @@ GLOBAL postmkvirtualenv"
     rm -f "$WORKON_HOME/premkvirtualenv"
     rm -f "$WORKON_HOME/postmkvirtualenv"
     deactivate
-    rmvirtualenv "env3"
+    rmvirtualenv "env3" >/dev/null 2>&1
 }
 
 test_no_virtualenv () {
@@ -105,7 +103,27 @@ test_mkvirtualenv_sitepackages () {
     mkvirtualenv --no-site-packages "without_sp" >/dev/null 2>&1
     ngsp_file="`virtualenvwrapper_get_site_packages_dir`/../no-global-site-packages.txt"
     assertTrue "$ngsp_file does not exist" "[ -f \"$ngsp_file\" ]"
-    rmvirtualenv "env4"
+    rmvirtualenv "env4" >/dev/null 2>&1
+}
+
+test_mkvirtualenv_hooks_system_site_packages () {
+    # See issue #189
+
+    echo "#!/bin/sh" > "$WORKON_HOME/premkvirtualenv"
+    echo "echo GLOBAL premkvirtualenv \`pwd\` \"\$@\" >> \"$TMPDIR/catch_output\"" >> "$WORKON_HOME/premkvirtualenv"
+    chmod +x "$WORKON_HOME/premkvirtualenv"
+
+    echo "echo GLOBAL postmkvirtualenv >> $TMPDIR/catch_output" > "$WORKON_HOME/postmkvirtualenv"
+    mkvirtualenv --system-site-packages "env189" >/dev/null 2>&1
+    output=$(cat "$TMPDIR/catch_output")
+    workon_home_as_pwd=$(cd $WORKON_HOME; pwd)
+    expected="GLOBAL premkvirtualenv $workon_home_as_pwd env189
+GLOBAL postmkvirtualenv"
+    assertSame "$expected" "$output"
+    rm -f "$WORKON_HOME/premkvirtualenv"
+    rm -f "$WORKON_HOME/postmkvirtualenv"
+    deactivate
+    rmvirtualenv "env189" >/dev/null 2>&1
 }
 
 test_mkvirtualenv_args () {
@@ -115,7 +133,7 @@ test_mkvirtualenv_args () {
     mkvirtualenv "without_sp2" >/dev/null 2>&1
     ngsp_file="`virtualenvwrapper_get_site_packages_dir`/../no-global-site-packages.txt"
     assertTrue "$ngsp_file does not exist" "[ -f \"$ngsp_file\" ]"
-    rmvirtualenv "env4"
+    rmvirtualenv "env4" >/dev/null 2>&1
     unset VIRTUALENVWRAPPER_VIRTUALENV_ARGS
 }
 
@@ -123,12 +141,12 @@ test_no_such_virtualenv () {
     VIRTUALENVWRAPPER_VIRTUALENV=/path/to/missing/program
 
     echo "#!/bin/sh" > "$WORKON_HOME/premkvirtualenv"
-    echo "echo GLOBAL premkvirtualenv \`pwd\` \"\$@\" >> \"$pre_test_dir/catch_output\"" >> "$WORKON_HOME/premkvirtualenv"
+    echo "echo GLOBAL premkvirtualenv \`pwd\` \"\$@\" >> \"$TMPDIR/catch_output\"" >> "$WORKON_HOME/premkvirtualenv"
     chmod +x "$WORKON_HOME/premkvirtualenv"
 
-    echo "echo GLOBAL postmkvirtualenv >> $test_dir/catch_output" > "$WORKON_HOME/postmkvirtualenv"
+    echo "echo GLOBAL postmkvirtualenv >> $TMPDIR/catch_output" > "$WORKON_HOME/postmkvirtualenv"
     mkvirtualenv "env3" >/dev/null 2>&1
-    output=$(cat "$test_dir/catch_output" 2>/dev/null)
+    output=$(cat "$TMPDIR/catch_output" 2>/dev/null)
     workon_home_as_pwd=$(cd $WORKON_HOME; pwd)
     expected=""
     assertSame "$expected" "$output"
@@ -151,12 +169,12 @@ test_virtualenv_fails () {
     VIRTUALENVWRAPPER_VIRTUALENV=false
 
     echo "#!/bin/sh" > "$WORKON_HOME/premkvirtualenv"
-    echo "echo GLOBAL premkvirtualenv \`pwd\` \"\$@\" >> \"$pre_test_dir/catch_output\"" >> "$WORKON_HOME/premkvirtualenv"
+    echo "echo GLOBAL premkvirtualenv \`pwd\` \"\$@\" >> \"$TMPDIR/catch_output\"" >> "$WORKON_HOME/premkvirtualenv"
     chmod +x "$WORKON_HOME/premkvirtualenv"
 
-    echo "echo GLOBAL postmkvirtualenv >> $test_dir/catch_output" > "$WORKON_HOME/postmkvirtualenv"
+    echo "echo GLOBAL postmkvirtualenv >> $TMPDIR/catch_output" > "$WORKON_HOME/postmkvirtualenv"
     mkvirtualenv "env3" >/dev/null 2>&1
-    output=$(cat "$test_dir/catch_output" 2>/dev/null)
+    output=$(cat "$TMPDIR/catch_output" 2>/dev/null)
     workon_home_as_pwd=$(cd $WORKON_HOME; pwd)
     expected=""
     assertSame "$expected" "$output"
@@ -174,5 +192,29 @@ test_mkvirtualenv_python_not_sticky () {
     VIRTUALENVWRAPPER_VIRTUALENV=$_save
 }
 
+test_mkvirtualenv_python_short_option () {
+    typeset _save=$VIRTUALENVWRAPPER_VIRTUALENV
+    VIRTUALENVWRAPPER_VIRTUALENV=echo
+    output="$(mkvirtualenv -p python foo)"
+    assertSame "--python=$(pwd)/python foo" "$output"
+    VIRTUALENVWRAPPER_VIRTUALENV=$_save
+}
+
+test_mkvirtualenv_python_long_option () {
+    typeset _save=$VIRTUALENVWRAPPER_VIRTUALENV
+    VIRTUALENVWRAPPER_VIRTUALENV=echo
+    output="$(mkvirtualenv --python python foo)"
+    assertSame "--python=$(pwd)/python foo" "$output"
+    VIRTUALENVWRAPPER_VIRTUALENV=$_save
+}
+
+test_mkvirtualenv_python_long_option_equal () {
+    typeset _save=$VIRTUALENVWRAPPER_VIRTUALENV
+    VIRTUALENVWRAPPER_VIRTUALENV=echo
+    output="$(mkvirtualenv --python=python foo)"
+    assertSame "--python=$(pwd)/python foo" "$output"
+    VIRTUALENVWRAPPER_VIRTUALENV=$_save
+}
+
 
 . "$test_dir/shunit2"
