@@ -146,7 +146,7 @@ function virtualenvwrapper_derive_workon_home {
         # - Removing extra slashes (e.g., when TMPDIR ends in a slash)
         # - Expanding variables (e.g., $foo)
         # - Converting ~s to complete paths (e.g., ~/ to /home/brian/ and ~arthur to /home/arthur)
-        workon_home_dir=$(virtualenvwrapper_expandpath "$workon_home_dir")
+        workon_home_dir="$(virtualenvwrapper_expandpath "$workon_home_dir")"
     fi
 
     echo "$workon_home_dir"
@@ -297,7 +297,7 @@ function virtualenvwrapper_initialize {
 
 # Verify that the passed resource is in path and exists
 function virtualenvwrapper_verify_resource {
-    typeset exe_path=$(command \which "$1" | (unset GREP_OPTIONS; command \grep -v "not found"))
+    typeset exe_path="$(command \which "$1" | (unset GREP_OPTIONS; command \grep -v "not found"))"
     if [ "$exe_path" = "" ]
     then
         echo "ERROR: virtualenvwrapper could not find $1 in your path" >&2
@@ -408,14 +408,19 @@ function mkvirtualenv {
             -i)
                 i=$(( $i + 1 ));
                 packages="$packages ${in_args[$i]}";;
-            -p|--python)
-                i=$(( $i + 1 ));
-                interpreter="${in_args[$i]}";
-                interpreter=$(virtualenvwrapper_absolutepath "$interpreter");;
+            -p|--python*)
+                if echo "$a" | grep -q "="
+                then
+                    interpreter="$(echo "$a" | cut -f2 -d=)"
+                else
+                    i=$(( $i + 1 ))
+                    interpreter="${in_args[$i]}"
+                fi;
+                interpreter="$(virtualenvwrapper_absolutepath "$interpreter")";;
             -r)
                 i=$(( $i + 1 ));
                 requirements="${in_args[$i]}";
-                requirements=$(virtualenvwrapper_expandpath "$requirements");;
+                requirements="$(virtualenvwrapper_expandpath "$requirements")";;
             *)
                 if [ ${#out_args} -gt 0 ]
                 then
@@ -529,8 +534,7 @@ function virtualenvwrapper_show_workon_options {
     # 4. Format the output to show one name on a line.
     # 5. Eliminate any lines with * on them because that means there 
     #    were no envs.
-    (echo $WORKON_HOME/*/$VIRTUALENVWRAPPER_ENV_BIN_DIR/activate) 2>/dev/null \
-        | command \sed "s|$WORKON_HOME/||g" \
+    (cd "$WORKON_HOME" && echo */$VIRTUALENVWRAPPER_ENV_BIN_DIR/activate) 2>/dev/null \
         | command \sed "s|/$VIRTUALENVWRAPPER_ENV_BIN_DIR/activate||g" \
         | command \fmt -w 1 \
         | (unset GREP_OPTIONS; command \egrep -v '^\*$') 2>/dev/null
@@ -587,10 +591,7 @@ function lsvirtualenv {
 
     if $long_mode
     then
-        for env_name in $(virtualenvwrapper_show_workon_options)
-        do
-            showvirtualenv "$env_name"
-        done
+        allvirtualenv showvirtualenv "$env_name"
     else
         virtualenvwrapper_show_workon_options
     fi
@@ -608,10 +609,9 @@ function showvirtualenv {
             echo "showvirtualenv [env]"
             return 1
         fi
-        env_name=$(basename $VIRTUAL_ENV)
+        env_name=$(basename "$VIRTUAL_ENV")
     fi
 
-    echo -n "$env_name"
     virtualenvwrapper_run_hook "get_env_details" "$env_name"
     echo
 }
@@ -797,7 +797,7 @@ function add2virtualenv {
 
     for pydir in "$@"
     do
-        absolute_path=$(virtualenvwrapper_absolutepath "$pydir")
+        absolute_path="$(virtualenvwrapper_absolutepath "$pydir")"
         if [ "$absolute_path" != "$pydir" ]
         then
             echo "Warning: Converting \"$pydir\" to \"$absolute_path\"" 1>&2
@@ -884,13 +884,13 @@ function cpvirtualenv {
             # so its a virtualenv we are importing
             # make sure we have a full path
             # and get the name
-            src=$(virtualenvwrapper_expandpath "$src_name")
+            src="$(virtualenvwrapper_expandpath "$src_name")"
             # final verification
             if [ ! -e "$src" ]; then
                 echo "Please provide a valid virtualenv to copy."
                 return 1
             fi
-            src_name=$(basename "$src")
+            src_name="$(basename "$src")"
         else
            src="$WORKON_HOME/$src_name"
         fi
@@ -904,7 +904,7 @@ function cpvirtualenv {
     else
         trg="$WORKON_HOME/$trg_name"
     fi
-    trg=$(virtualenvwrapper_expandpath "$trg")
+    trg="$(virtualenvwrapper_expandpath "$trg")"
 
     # validate trg does not already exist
     # catch copying virtualenv in workon home
@@ -1075,7 +1075,7 @@ function cdproject {
     virtualenvwrapper_verify_active_environment || return 1
     if [ -f "$VIRTUAL_ENV/$VIRTUALENVWRAPPER_PROJECT_FILENAME" ]
     then
-        typeset project_dir=$(cat "$VIRTUAL_ENV/$VIRTUALENVWRAPPER_PROJECT_FILENAME")
+        typeset project_dir="$(cat "$VIRTUAL_ENV/$VIRTUALENVWRAPPER_PROJECT_FILENAME")"
         if [ ! -z "$project_dir" ]
         then
             cd "$project_dir"
@@ -1131,6 +1131,47 @@ fi
 EOF
 }
 
+#
+# Remove all installed packages from the env
+#
+function wipeenv {
+    virtualenvwrapper_verify_workon_home || return 1
+    virtualenvwrapper_verify_active_environment || return 1
+
+    typeset req_file="$(virtualenvwrapper_tempfile "requirements.txt")"
+    pip freeze | egrep -v '(distribute|wsgiref)' > "$req_file"
+    if [ -n "$(cat "$req_file")" ]
+    then
+        echo "Uninstalling packages:"
+        cat "$req_file"
+        echo
+        pip uninstall -y $(cat "$req_file" | sed 's/>/=/g' | cut -f1 -d=)
+    else
+        echo "Nothing to remove."
+    fi
+    rm -f "$req_file"
+}
+
+#
+# Run a command in each virtualenv
+#
+function allvirtualenv {
+    virtualenvwrapper_verify_workon_home || return 1
+    typeset d
+
+    virtualenvwrapper_show_workon_options | while read d
+    do
+        [ ! -d "$WORKON_HOME/$d" ] && continue
+        echo "$d"
+        echo "$d" | sed 's/./=/g'
+        # Activate the environment, but not with workon
+        # because we don't want to trigger any hooks.
+        (source "$WORKON_HOME/$d/bin/activate";
+            cd "$VIRTUAL_ENV";
+            $@)
+        echo
+    done
+}
 
 #
 # Invoke the initialization functions
